package com.nifty.cloud.ncs.service;

/**
 * ニフクラストレージのバケットオーナー情報を保持するクラスです。
 */
public class Owner
{
	private String displayName = "";
	private String userId = "";

	/**
	 * ユーザーIDと契約者名を指定せずに新しいOwnerを構築します。
	 *
	 */
	public Owner()
	{
	}

	/**
	 * 指定したユーザーID、および契約者名を使用して新しいOwnerを構築します。
	 *
	 * @param userId
	 *  オーナーのユーザーID
	 * @param displayName
	 *  オーナーの契約者名
	 */
	public Owner(String userId, String displayName)
	{
		this.userId = userId;
		this.displayName = displayName;
	}

	/**
	 * オーナーのユーザーIDを設定します。
	 *
	 * @param userId
	 *  オーナーのユーザーID
	 */
	public void setUserId(String userId)
	{
		this.userId = userId;
	}

	/**
	 * オーナーのユーザーIDを取得します。
	 *
	 * @return
	 *  オーナーのユーザーID
	 */
	public String getUserId()
	{
		return (userId);
	}

	/**
	 * オーナーの契約者名を設定します。
	 *
	 * @param displayName
	 *  オーナーの契約者名
	 */
	public void setDisplayName(String displayName)
	{
		this.displayName = displayName;
	}

	/**
	 * オーナーの契約者名を取得します。
	 *
	 * @return
	 *  オーナーの契約者名
	 */
	public String getDisplayName()
	{
		return (displayName);
	}

	@Override
	public String toString()
	{
		StringBuilder sb = new StringBuilder();
		sb.append("Owner [name=");
		sb.append(displayName);
		sb.append(", id=");
		sb.append(userId);
		sb.append("]");

		return (sb.toString());
	}
}
